#
# spec file for package postsrsd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           postsrsd
Version:        2.0.8
Release:        1.2
Summary:        Sender Rewriting Support for postfix
License:        GPL-2.0-only
Group:          Productivity/Networking/Email/Servers
URL:            https://github.com/roehling/postsrsd
Source:         https://github.com/roehling/postsrsd/archive/%version.tar.gz
Source3:        sysuser.conf
BuildRequires:  cmake >= 3.24
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(libconfuse)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(systemd)

%description
PostSRSd provides the Sender Rewriting Scheme (SRS) via TCP-based
lookup tables for Postfix. SRS is needed if your mail server acts
as forwarder.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %_sourcedir/sysuser.conf %name postsrsd.conf
%cmake -DFETCHCONTENT_TRY_FIND_PACKAGE_MODE=ALWAYS \
	-DGENERATE_SRS_SECRET=0 -DCHROOT_DIR=/var/lib/postsrsd \
	-DUSE_APPARMOR=1 -DINIT_FLAVOR=systemd \
	-DWITH_SQLITE=BOOL:ON -DBUILD_TESTING:BOOL=OFF \
	-DPOSTSRSD_USER=postsrsd
%make_jobs

%install
%cmake_install
b="%buildroot"
mkdir -p "$b/%_defaultdocdir"
mv "$b/%_datadir/doc/%name" "$b/%_defaultdocdir/"
cp README.rst "$b/%_defaultdocdir/%name/"

mkdir -p "$b/%_sysusersdir" "$b/var/lib/postsrsd"
install -m 0644 "%_sourcedir/sysuser.conf" "$b/%_sysusersdir/postsrsd.conf"

%pre -f %name.pre
%service_add_pre postsrsd.service

%post
s="%_sysconfdir/postsrsd.secret"
if [ ! -e "$s" ]; then
	echo "No postsrsd secret found in $s, generating one."
	dd if=/dev/urandom of="$s" bs=64 count=1
fi
%service_add_post postsrsd.service

%preun
%service_del_preun postsrsd.service

%postun
%service_del_postun postsrsd.service

%files
%_sbindir/postsrsd
%_sysusersdir/*
%_unitdir/*
%_defaultdocdir/%name/
%attr(0750,postsrsd,postsrsd) /var/lib/postsrsd
%license LICENSES/*

%changelog
* Fri Aug 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.8
  * Fixed socket creation for Milter
  * Fixed Milter issue with IPv6 clients
* Sat Aug 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.7
  * The parser callback for the original-envelope option used the
    wrong return type, which could prevent the database mode from
    activating.
* Sat Jul 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.6
  * New configuration option debug to increase log verbosity
  * Reduced default log verbosity: PostSRSd no longer prints
    messages for mail addresses which need no rewrite
* Tue Jun 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.5
  * Do not try to set Keep-Alive on Redis unix sockets
* Wed May  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.4
  * Added new CLI option -h to print a summary of CLI options
  * Improved error logging
* Sun Mar  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.3
  * Close socketmap connection in main process to prevent resource
    exhaustion
  * Explicitly set 0666 permissions on socketmap unix socket
* Mon Jan 16 2023 Jan Engelhardt <jengelh@inai.de>
- Switch the default execution user from "nobody" to the new
  "postsrsd". /var/lib/postsrsd will be owned by postsrsd. If
  /etc/postsrsd.conf contains a "unprivileged-user" override,
  it needs to be adjusted.
* Sat Jan  7 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.2
  * Everything thrown over the fence, this is a complete rewrite
    of PostSRSd.
  * Configuration file, no more fiddling with environment variables.
  * Support for socketmap table (Postfix 2.10 or newer required).
  * Unix socket support
  * Rewrite mode with database backend, supports unlimited email
    address length.
  * Experimental Milter support.
* Wed Aug 17 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.12
  * Explicitly clear O_NONBLOCK to avoid inherited non-blocking
    sockets on some operating systems
  * Do not close all file descriptors up to _SC_MAX_OPEN, that
    limit can be absurdly high and hang PostSRSd for minutes
* Mon Apr 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.11 [boo#1180251]
  * Drop group privileges as well as user privileges
  * Fixed: The subprocess that talks to Postfix could be caused
    to hang with a very long email address. [CVE-2020-35573]
* Fri Dec 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6
  * Fix endianness issue with SHA-1 implementation
  * Add dual stack support
  * Make SRS separator configurable
* Tue Nov 18 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 1.2+git2)
